# hallo-ut

[![hallo-ut - PyPi](https://img.shields.io/pypi/v/hallo-ut)](https://pypi.org/project/hallo-ut/)
[![Supported Python versions](https://img.shields.io/pypi/pyversions/hallo-ut)](https://pypi.org/project/hallo-ut/)
[![LICENSE](https://img.shields.io/github/license/UnivTerbuka/hallo-ut)](https://github.com/UnivTerbuka/hallo-ut/blob/main/LICENSE)
[![Code Style - Black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

SDK Python Layanan Informasi & Bantuan Universitas Terbuka

## Install

Install dengan [python](https://www.python.org/)

```bash
pip install --upgrade hallo-ut
```

## Penggunaan

Penggunaan sederhana

```bash
python -m hallo-ut "pertanyaan anda atau tiket hallo-ut anda"
```

## Legal / Hukum

Kode ini sama sekali tidak berafiliasi dengan, diizinkan, dipelihara, disponsori atau didukung oleh [Universitas Terbuka](https://ut.ac.id/) atau afiliasi atau anak organisasinya. Ini adalah perangkat lunak yang independen dan tidak resmi. Gunakan dengan risiko Anda sendiri.
